#!/usr/bin/env python3

import pandas as pd
import sys
import os

def replace_newlines(input_file):
    # Vérifier si le fichier existe
    if not os.path.isfile(input_file):
        print(f"Le fichier {input_file} n'existe pas.")
        return

    # Charger le fichier CSV
    df = pd.read_csv(input_file)

    # Remplacer les retours à la ligne par "\\n" dans chaque colonne
    df.replace(to_replace=r'\r?\n', value=r'\\n', regex=True, inplace=True)

    # Construire le nom du fichier de sortie
    base, ext = os.path.splitext(input_file)
    output_file = f"{base}_modified{ext}"

    # Sauvegarder le fichier modifié
    df.to_csv(output_file, index=False)
    print(f"Fichier modifié sauvegardé sous le nom : {output_file}")

if __name__ == "__main__":
    if len(sys.argv) < 2:
        print("Usage: python replace_newlines.py <file1.csv> <file2.csv> ...")
    else:
        for input_file in sys.argv[1:]:
            replace_newlines(input_file)

